@@ -2,7 +2,7 @@
     Copyright (C) 2007-2008 Tanguy Krotoff <tkrotoff@gmail.com>
     Copyright (C) 2008 Lukas Durfina <lukas.durfina@gmail.com>
     Copyright (C) 2009 Fathi Boudra <fabo@kde.org>
-    Copyright (C) 2009-2011 vlc-phonon AUTHORS
+    Copyright (C) 2009-2011 vlc-phonon AUTHORS <kde-multimedia@kde.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public
@@ -27,8 +27,6 @@
 #include "utils/debug.h"
 #include "media.h"
 #include "mediaobject.h"
-
-QT_BEGIN_NAMESPACE
 #ifndef QT_NO_PHONON_ABSTRACTMEDIASTREAM
 
 namespace Phonon {
@@ -178,7 +176,7 @@ bool StreamReader::read(quint64 pos, int *length, char *buffer)
         enoughData();
     }
 
-    qMemCopy(buffer, m_buffer.data(), *length);
+    memcpy(buffer, m_buffer.data(), *length);
     m_pos += *length;
     // trim the buffer by the amount read
     m_buffer = m_buffer.mid(*length);
@@ -242,5 +240,3 @@ bool StreamReader::streamSeekable() const
 } // namespace Phonon
 
 #endif //QT_NO_PHONON_ABSTRACTMEDIASTREAM
-
-QT_END_NAMESPACE
