@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 2011 vlc-phonon AUTHORS
+    Copyright (C) 2011 vlc-phonon AUTHORS <kde-multimedia@kde.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public
@@ -23,8 +23,6 @@
 
 #include <vlc/libvlc_version.h>
 
-class QLibrary;
-
 struct libvlc_instance_t;
 
 /**
@@ -136,26 +134,7 @@ private:
      */
     LibVLC();
 
-    /**
-     * Get VLC path.
-     *
-     * @return the VLC path
-     */
-    QString vlcPath();
-
-    /**
-     * Unload VLC library.
-     */
-    void vlcUnload();
-
-#if defined(Q_OS_UNIX)
-     static bool libGreaterThan(const QString &lhs, const QString &rhs);
-#endif // defined(Q_OS_UNIX)
-
-     static QStringList findAllLibVlcPaths();
-
-     QLibrary *m_vlcLibrary;
-     libvlc_instance_t *m_vlcInstance;
+    libvlc_instance_t *m_vlcInstance;
 };
 
 #endif // LIBVLC_H
